summaryrefslogtreecommitdiff
path: root/node/Switch.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'node/Switch.hpp')
-rw-r--r--node/Switch.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/node/Switch.hpp b/node/Switch.hpp
index 0d1828be..71e1e386 100644
--- a/node/Switch.hpp
+++ b/node/Switch.hpp
@@ -113,11 +113,11 @@ public:
* Send a HELLO announcement immediately to the indicated address
*
* @param localPort Originating local port or ANY_PORT to pick
* @param addr IP address to send to
* @param dest Destination peer
* @return True if send appears successful
*/
- bool sendHELLO(const SharedPtr<Peer> &dest,Demarc::Port localPort,const InetAddress &addr);
+ bool sendHELLO(const SharedPtr<Peer> &dest,Demarc::Port localPort,const InetAddress &remoteAddr);
/**
* Send RENDEZVOUS to two peers to permit them to directly connect
@@ -113,11 +113,11 @@ public:
*
* @param localPort Originating local port or ANY_PORT to pick
- * @param addr IP address to send to
+ * @param remoteAddr IP address to send to
* @param dest Destination peer
* @return True if send appears successful